==> rustc_1.90.0+dfsg1.orig.tar.xz: rustc-1.90.0-src/src/etc/rust_analyzer_eglot.el <==
((rustic-mode
  .((eglot-workspace-configuration
     . (:rust-analyzer
        ( :check ( :invocationLocation "root"
                                       :invocationStrategy "once"
                                       :overrideCommand ["python3"
                                                         "x.py"
                                                         "check"
                                                         "--json-output"])
                 :linkedProjects ["Cargo.toml"
                                  "compiler/rustc_codegen_cranelift/Cargo.toml"
                                  "compiler/rustc_codegen_gcc/Cargo.toml"
                                  "library/Cargo.toml"
                                  "src/bootstrap/Cargo.toml"
                                  "src/tools/rust-analyzer/Cargo.toml"]
                 :rustfmt ( :overrideCommand ["build/host/rustfmt/bin/rustfmt"
                                              "--edition=2024"])
                 :procMacro ( :server "build/host/stage0/libexec/rust-analyzer-proc-macro-srv"
                                      :enable t)
                 :cargo ( :buildScripts ( :enable t
                                                  :invocationLocation "root"
                                                  :invocationStrategy "once"
                                                  :overrideCommand ["python3"
                                                                    "x.py"
                                                                    "check"
                                                                    "--json-output"
                                                                    "--compile-time-deps"])]
                                        :sysrootSrc "./library"
                                        :extraEnv (:RUSTC_BOOTSTRAP "1"))
                 :rustc ( :source "./Cargo.toml" )))))))

==> rustc_1.92.0+dfsg1.orig.tar.xz: rustc-1.92.0-src/src/etc/rust_analyzer_eglot.el <==
((rustic-mode
  .((eglot-workspace-configuration
     . (:rust-analyzer
        ( :check ( :invocationLocation "root"
                                       :invocationStrategy "once"
                                       :overrideCommand ["python3"
                                                         "x.py"
                                                         "check"
                                                         "--build-dir"
                                                         "build-rust-analyzer"
                                                         "--json-output"])
                 :linkedProjects ["Cargo.toml"
                                  "compiler/rustc_codegen_cranelift/Cargo.toml"
                                  "compiler/rustc_codegen_gcc/Cargo.toml"
                                  "library/Cargo.toml"
                                  "src/bootstrap/Cargo.toml"
                                  "src/tools/rust-analyzer/Cargo.toml"]
                 :rustfmt ( :overrideCommand ["build-rust-analyzer/host/rustfmt/bin/rustfmt"
                                              "--edition=2024"])
                 :procMacro ( :server "build-rust-analyzer/host/stage0/libexec/rust-analyzer-proc-macro-srv"
                                      :enable t)
                 :cargo ( :buildScripts ( :enable t
                                                  :invocationLocation "root"
                                                  :invocationStrategy "once"
                                                  :overrideCommand ["python3"
                                                                    "x.py"
                                                                    "check"
                                                                    "--build-dir"
                                                                    "build-rust-analyzer"
                                                                    "--json-output"
                                                                    "--compile-time-deps"])]
                                        :sysrootSrc "./library"
                                        :extraEnv (:RUSTC_BOOTSTRAP "1"))
                 :rustc ( :source "./Cargo.toml" )))))))
